==================
Function reference
==================

Bottleneck provides the following functions:

======================= =======================================================================================================================
NumPy/SciPy             :meth:`median <bottlechest.median>`, :meth:`nanmedian <bottlechest.nanmedian>`, :meth:`rankdata <bottlechest.rankdata>`,
                        :meth:`ss <bottlechest.ss>`, :meth:`nansum <bottlechest.nansum>`, :meth:`nanmin <bottlechest.nanmin>`,
                        :meth:`nanmax <bottlechest.nanmax>`, :meth:`nanmean <bottlechest.nanmean>`, :meth:`nanstd <bottlechest.nanstd>`,
                        :meth:`nanargmin <bottlechest.nanargmin>`, :meth:`nanargmax <bottlechest.nanargmax>` 
Functions               :meth:`nanrankdata <bottlechest.nanrankdata>`, :meth:`nanvar <bottlechest.nanvar>`,
                        :meth:`partsort <bottlechest.partsort>`, :meth:`argpartsort <bottlechest.argpartsort>`,
                        :meth:`replace <bottlechest.replace>`, :meth:`nn <bottlechest.nn>`, :meth:`anynan <bottlechest.anynan>`,
                        :meth:`allnan <bottlechest.allnan>`
Moving window           :meth:`move_sum <bottlechest.move_sum>`, :meth:`move_nansum <bottlechest.move_nansum>`,
                        :meth:`move_mean <bottlechest.move_mean>`, :meth:`move_nanmean <bottlechest.move_nanmean>`,
                        :meth:`move_median <bottlechest.move_median>`,
                        :meth:`move_std <bottlechest.move_std>`, :meth:`move_nanstd <bottlechest.move_nanstd>`,
                        :meth:`move_min <bottlechest.move_min>`, :meth:`move_nanmin <bottlechest.move_nanmin>`,
                        :meth:`move_max <bottlechest.move_max>`, :meth:`move_nanmax <bottlechest.move_nanmax>`
======================= =======================================================================================================================


NumPy/SciPy
-----------

Fast replacements for NumPy and SciPy functions.

------------

.. autofunction:: bottlechest.median

------------
             
.. autofunction:: bottlechest.nanmedian

------------

.. autofunction:: bottlechest.rankdata

------------

.. autofunction:: bottlechest.ss

------------

.. autofunction:: bottlechest.nansum

------------

.. autofunction:: bottlechest.nanmin

------------

.. autofunction:: bottlechest.nanmax

------------
             
.. autofunction:: bottlechest.nanmean

------------

.. autofunction:: bottlechest.nanstd

------------

.. autofunction:: bottlechest.nanargmin

------------

.. autofunction:: bottlechest.nanargmax


Functions
---------

Miscellaneous functions.

------------

.. autofunction:: bottlechest.nanrankdata

------------

.. autofunction:: bottlechest.nanvar

------------

.. autofunction:: bottlechest.partsort

------------

.. autofunction:: bottlechest.argpartsort

------------

.. autofunction:: bottlechest.replace

------------

.. autofunction:: bottlechest.nn

------------

.. autofunction:: bottlechest.anynan

------------

.. autofunction:: bottlechest.allnan


Moving window functions
-----------------------

Moving window functions with a 1d window.

------------

.. autofunction:: bottlechest.move_sum

------------

.. autofunction:: bottlechest.move_nansum

------------

.. autofunction:: bottlechest.move_mean

------------

.. autofunction:: bottlechest.move_nanmean

------------

.. autofunction:: bottlechest.move_median

------------

.. autofunction:: bottlechest.move_std

------------

.. autofunction:: bottlechest.move_nanstd

------------

.. autofunction:: bottlechest.move_min

------------

.. autofunction:: bottlechest.move_nanmin

------------

.. autofunction:: bottlechest.move_max

------------

.. autofunction:: bottlechest.move_nanmax
